=======
History
=======

0.2.2 (2021-02-28)
------------------

* Allow start with no connection (also allow to remove the last connection)
* Display warning headers from server
* Support the HEAD http method
* Smart date math expression handling
* Support post-event callback for both session and connection
* Display now takes formatted text for style and color

0.2.1 (2020-09-22)
------------------

* Fix distribution packaging

0.2.0 (2020-09-20)
------------------

* Auto-completion is fully functional
* Various improvements


0.1.1 (2020-08-29)
------------------

* Support persisting session across restart of the CLI


0.1.0 (2020-07-22)
------------------

* First commit
